@@ -1,5 +1,6 @@
 import json
 import os
+import magic
 from io import BytesIO
 
 from django.conf import settings
@@ -87,7 +88,7 @@ class Media(TranslatableModel):
     created = models.DateTimeField(auto_now=True)
     name = models.CharField(max_length=200, blank=True, null=True)
     size = models.IntegerField(default=0, blank=True, null=True)
-    is_image = models.BooleanField(default=False)
+    mime_type = models.CharField(max_length=128, blank=True, null=True)
     image_props = JSONField(default=dict, blank=True)
     folder = models.ForeignKey(
         MediaFolder,
@@ -101,6 +102,10 @@ class Media(TranslatableModel):
     def path(self):
         return "%s/%s" % (self.folder.path, self.name)
 
+    @property
+    def is_image(self):
+        return self.mime_type and self.mime_type.startswith("image")
+
     def image_preview(self):
         if self.file:
             return mark_safe('<img src="{0}" />'.format(self.file.url))
@@ -136,23 +141,21 @@ class Media(TranslatableModel):
         return json.dumps(json_r)
 
     def _make_thumbnail(self):
-
         try:
             fh = storage.open(self.file.name, "rb")
+            self.mime_type = magic.from_buffer(fh.read(2048), mime=True)
         except FileNotFoundError as ex:
             print(ex)
-            self.is_image = False
             self.image_props = {}
+            self.mime_type = ""
             return False
         try:
             orig_image = Image.open(fh)
             image = orig_image.copy()
-            self.is_image = True
             self.image_props = {
                 "width": orig_image.width,
                 "height": orig_image.height,
                 "format": orig_image.format,
-                "mime": Image.MIME[orig_image.format],
                 "mode": orig_image.mode,
             }
         except Exception as ex:
@@ -222,7 +225,7 @@ def update_media(sender, instance, **kwargs):
     Media.objects.filter(pk=instance.pk).update(
         size=instance._get_file_size(),
         thumbnail=instance.thumbnail,
-        is_image=instance.is_image,
+        mime_type=instance.mime_type,
         image_props=instance.image_props,
     )
 
